==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/General/kdenotify/translations/kdenotify_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="122"/>
        <source>Qmmp now playing:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="30"/>
        <source>KDE 4 notification plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="50"/>
        <source>About KDE Notification Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="51"/>
        <source>KDE 4 notification plugin for Qmmp 
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>KDE 4 Notification Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Notification delay [s]:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Update visible notification instead create new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Show covers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="75"/>
        <source>Notification Template</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/kdenotify/translations/kdenotify_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="121"/>
        <source>Qmmp now playing:</source>
        <translation>Qmmp tocando agora:</translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="32"/>
        <source>KDE 4 notification plugin</source>
        <translation>Plugin KDE 4 Notification</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="52"/>
        <source>About KDE Notification Plugin</source>
        <translation>Sobre o plugin KDE Notification</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="53"/>
        <source>KDE 4 notification plugin for Qmmp 
</source>
        <translation>Plugin KDE 4 Notification para o Qmmp </translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>KDE 4 Notification Plugin Settings</source>
        <translation>Preferências do plugin KDE 4 Notification </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Notification delay [s]:</source>
        <translation>Atraso da notificação [s]:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Update visible notification instead create new</source>
        <translation>Atualizar notificação em vez de criar uma nova</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Show covers</source>
        <translation>Mostrar capa de álbum</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Edit template</source>
        <translation>Editar modelo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="75"/>
        <source>Notification Template</source>
        <translation>Modelo da notificação</translation>
    </message>
</context>
</TS>
